--- old/usr/src/man/man9f/ddi_periodic_add.9f	Wed Jul 24 19:01:28 2013
+++ new/usr/src/man/man9f/ddi_periodic_add.9f	Wed Jul 24 19:01:28 2013
@@ -1,11 +1,12 @@
 '\" te
 .\"  Copyright (c) 2009, Sun Microsystems, Inc. All Rights Reserved
+.\" Copyright 2013, Joyent, Inc. All Rights Reserved.
 .\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License").  You may not use this file except in compliance with the License. You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.
 .\"  See the License for the specific language governing permissions and limitations under the License. When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE.  If applicable, add the following below this CDDL HEADER, with
 .\" the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH DDI_PERIODIC_ADD 9F "Apr 13, 2009"
+.TH DDI_PERIODIC_ADD 9F "Jul 23, 2013"
 .SH NAME
-ddi_periodic_add \- issue nanosecond periodic timeout requests
+ddi_periodic_add \- request periodic function invocation
 .SH SYNOPSIS
 .LP
 .nf
@@ -27,9 +28,7 @@
 \fB\fIfunc\fR\fR
 .ad
 .RS 12n
-The callback function is invoked periodically in the specified interval. If the
-argument level is zero, the function is invoked in kernel context. Otherwise,
-it's invoked in interrupt context at the specified level.
+The callback function to be invoked periodically in the specified interval.
 .RE
 
 .sp
@@ -47,7 +46,7 @@
 \fB\fIinterval\fR\fR
 .ad
 .RS 12n
-Interval time in nanoseconds.
+The periodic interval time in nanoseconds.
 .RE
 
 .sp
@@ -56,12 +55,13 @@
 \fB\fIlevel\fR\fR
 .ad
 .RS 12n
-Callback interrupt level. If the value is zero, the callback function is
-invoked in kernel context. If the value is more than zero, but less than or
-equal to ten, the callback function is invoked in interrupt context at the
-specified interrupt level, which may be used for real time applications.
+The callback function is invoked at this priority level.  If the value of
+\fIlevel\fR is zero, the callback function is invoked in kernel context.
+If the value is greater than zero, but less than or equal to ten, the callback
+function is invoked in interrupt context at the specified interrupt level,
+which may be used for real time applications.
 .sp
-This value must be in range of 0-10, which can be either a numeric number, a
+This value must be in range of 0-10, which can be either an integer literal, a
 pre-defined macro (\fBDDI_IPL_0\fR, ... , \fBDDI_IPL_10\fR), or the
 \fBDDI_INTR_PRI\fR macro with the interrupt priority.
 .RE
@@ -75,13 +75,15 @@
 .LP
 As with \fBtimeout\fR(9F), the exact time interval over which the function
 takes effect cannot be guaranteed, but the value given is a close
-approximation.
+approximation.  If the callback function has not finished execution when the
+next interval expires, the system will skip running the callback for that
+interval.
 .SH RETURN VALUES
 .sp
 .LP
-\fBddi_periodic_add()\fRreturns the non-zero opaque value
-(\fBddi_periodic_t\fR), which might be used for \fBddi_periodic_delete\fR(9F)
-to specify the request.
+\fBddi_periodic_add()\fR returns the non-zero opaque value
+(\fBddi_periodic_t\fR), which is later used to cancel the periodic request
+with \fBddi_periodic_delete\fR(9F).
 .SH CONTEXT
 .sp
 .LP
@@ -108,7 +110,7 @@
 
          mutex_enter(&statep->lock);
          if (load_unbalanced(statep)) {
-             balance_tasks(statep);
+                 balance_tasks(statep);
          }
          mutex_exit(&statep->lock);
 }
@@ -118,8 +120,7 @@
 {
          hrtime_t interval = CHECK_INTERVAL;
 
-         mutex_init(&statep->lock, NULL, MUTEX_DRIVER,
-             (void *)DDI_IPL_0);
+         mutex_init(&statep->lock, NULL, MUTEX_DRIVER, DDI_IPL_0);
 
          /*
           * Register my_callback which is invoked periodically
@@ -154,8 +155,7 @@
   {
           hrtime_t interval = MONITOR_INTERVAL;
 
-          mutex_init(&statep->lock, NULL, MUTEX_DRIVER,
-              (void *)DDI_IPL_7);
+          mutex_init(&statep->lock, NULL, MUTEX_DRIVER, DDI_IPL_7);
 
           /*
            * Register the callback function invoked periodically
@@ -172,11 +172,10 @@
 .LP
 \fBcv_timedwait\fR(9F), \fBddi_intr_get_pri\fR(9F),
 \fBddi_periodic_delete\fR(9F), \fBddi_intr_get_softint_pri\fR(9F),
-\fBdelay\fR(9F), \fBdrv_usectohz\fR(9F), \fBqtimeout\fR(9F),
-\fBquntimeout\fR(9F), \fBtimeout\fR(9F), \fBuntimeout\fR(9F)
+\fBqtimeout\fR(9F), \fBquntimeout\fR(9F), \fBtimeout\fR(9F), \fBuntimeout\fR(9F)
 .SH NOTES
 .sp
 .LP
-A caller can only specify an interval in an integral multiple of 10ms. No other
-values are supported at this time. The interval specified is a lower bound on
-the interval on which the callback occurs.
+The caller must specify \fIinterval\fR as an even, non-zero multiple of 10ms.
+No other values are supported at this time. The interval specified is a lower
+bound on the interval between executions of the callback.
